@@ -1,7 +1,7 @@
 package CPAN::Info::FromURL;
 
-our $DATE = '2016-03-07'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-11-07'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -19,6 +19,12 @@ our $re_mod      = qr/(?:\w+(?:::\w+)*)/;
 our $re_version  = qr/(?:v?[0-9]+(?:\.[0-9]+)*(?:_[0-9]+|-TRIAL)?)/;
 our $re_end_or_q = qr/(?:[?&]|\z)/;
 
+sub _normalize_mod {
+    my $mod = shift;
+    $mod =~ s/'/::/g;
+    $mod;
+}
+
 $SPEC{extract_cpan_info_from_url} = {
     v => 1.1,
     summary => 'Extract/guess information from a URL',
@@ -118,6 +124,16 @@ _
             args => {url=>'http://search.cpan.org/search?mode=module&query=DBIx%3A%3AClass'},
             result => {site=>'sco', module=>'DBIx::Class'},
         },
+        {
+            name => 'sco/search?module=MOD',
+            args => {url=>'http://search.cpan.org/search?module=ToolSet'},
+            result => {site=>'sco', module=>'ToolSet'},
+        },
+        {
+            name => 'sco/search?module=MOD (#2)',
+            args => {url=>'http://search.cpan.org/search?module=Acme::Don\'t'},
+            result => {site=>'sco', module=>'Acme::Don::t'},
+        },
         {
             name => 'sco/~AUTHOR',
             args => {url=>'http://search.cpan.org/~unera?'},
@@ -151,6 +167,12 @@ _
             result => {site=>'cpanratings', dist=>'Submodules'},
         },
 
+        {
+            name => 'perldoc.perl.org/MOD/SUBMOD.html',
+            args => {url=>'http://perldoc.perl.org/Module/CoreList.html'},
+            result => {site=>'perldoc.perl.org', module=>'Module::CoreList'},
+        },
+
         {
             name => 'rt/(Public/)Dist/Display.html?Queue=DIST',
             args => {url=>'https://rt.cpan.org/Dist/Display.html?Queue=Perinci-Sub-Gen-AccessTable-DBI'},
@@ -234,7 +256,7 @@ sub extract_cpan_info_from_url {
             if ($url =~ m![?&]mode=module(?:&|\z)! && $
                     url =~ m![?&]query=(.+?)(?:&|\z)!) {
                 require URI::Escape;
-                $res->{module} = URI::Escape::uri_unescape($1);
+                $res->{module} = _normalize_mod(URI::Escape::uri_unescape($1));
             } elsif ($url =~ m![?&]mode=dist(?:&|\z)! && $
                     url =~ m![?&]query=(.+?)(?:&|\z)!) {
                 require URI::Escape;
@@ -243,6 +265,10 @@ sub extract_cpan_info_from_url {
                     url =~ m![?&]query=(.+?)(?:&|\z)!) {
                 require URI::Escape;
                 $res->{author} = URI::Escape::uri_unescape($1);
+            # used by some articles
+            } elsif ($url =~ m![?&]module=(.+?)(?:&|\z)!) {
+                require URI::Escape;
+                $res->{module} = _normalize_mod(URI::Escape::uri_unescape($1));
             }
         } elsif ($url =~ s!\A~(\w+)/?!!) {
             $res->{author} = $1;
@@ -269,6 +295,15 @@ sub extract_cpan_info_from_url {
             $res->{dist} = $1;
         }
 
+    } elsif ($url =~ s!\A$re_proto_http?perldoc\.perl\.org/?!!i) {
+
+        $res->{site} = 'perldoc.perl.org';
+        if ($url =~ m!^(\w+(?:/\w+)*)\.html!) {
+            my $mod = $1;
+            $mod =~ s!/!::!g;
+            $res->{module} = $mod;
+        }
+
     } elsif ($url =~ s!\A$re_proto_http?rt\.cpan\.org/?!!i) {
 
         $res->{site} = 'rt';
@@ -311,7 +346,7 @@ CPAN::Info::FromURL - Extract/guess information from a URL
 
 =head1 VERSION
 
-This document describes version 0.06 of CPAN::Info::FromURL (from Perl distribution CPAN-Info-FromURL), released on 2016-03-07.
+This document describes version 0.07 of CPAN::Info::FromURL (from Perl distribution CPAN-Info-FromURL), released on 2016-11-07.
 
 =head1 FUNCTIONS
 
@@ -324,15 +359,15 @@ Examples:
 
 =over
 
-=item * Example #1:
+=item * Example #1 (mcpan/pod/MOD):
 
  extract_cpan_info_from_url("https://metacpan.org/pod/Foo::Bar"); # -> { module => "Foo::Bar", site => "mcpan" }
 
-=item * Example #2:
+=item * Example #2 (mcpan/module/MOD):
 
  extract_cpan_info_from_url("metacpan.org/module/Foo?"); # -> { module => "Foo", site => "mcpan" }
 
-=item * Example #3:
+=item * Example #3 (mcpan/pod/release/AUTHOR/DIST-VERSION/lib/MOD.pm):
 
  extract_cpan_info_from_url("http://metacpan.org/pod/release/SRI/Mojolicious-6.46/lib/Mojo.pm");
 
@@ -346,7 +381,7 @@ Result:
    version => 6.46,
  }
 
-=item * Example #4:
+=item * Example #4 (mcpan/pod/release/AUTHOR/DIST-VERSION/bin/SCRIPT):
 
  extract_cpan_info_from_url("http://metacpan.org/pod/release/PERLANCAR/App-PMUtils-1.23/bin/pmpath");
 
@@ -360,7 +395,7 @@ Result:
    version => 1.23,
  }
 
-=item * Example #5:
+=item * Example #5 (mcpan/source/AUTHOR/DIST-VERSION/lib/MOD.pm):
 
  extract_cpan_info_from_url("http://metacpan.org/source/SRI/Mojolicious-6.46/lib/Mojo.pm?");
 
@@ -374,7 +409,7 @@ Result:
    version => 6.46,
  }
 
-=item * Example #6:
+=item * Example #6 (api.mcpan/source/AUTHOR/DIST-VERSION):
 
  extract_cpan_info_from_url("http://api.metacpan.org/source/SRI/Mojolicious-6.46?");
 
@@ -382,11 +417,11 @@ Result:
 
  { author => "SRI", dist => "Mojolicious", site => "mcpan", version => 6.46 }
 
-=item * Example #7:
+=item * Example #7 (mcpan/release/DIST):
 
  extract_cpan_info_from_url("https://metacpan.org/release/Foo-Bar"); # -> { dist => "Foo-Bar", site => "mcpan" }
 
-=item * Example #8:
+=item * Example #8 (mcpan/release/AUTHOR/DIST-VERSION):
 
  extract_cpan_info_from_url("https://metacpan.org/release/FOO/Bar-1.23");
 
@@ -394,11 +429,11 @@ Result:
 
  { author => "FOO", dist => "Bar", site => "mcpan", version => 1.23 }
 
-=item * Example #9:
+=item * Example #9 (mcpan/author/AUTHOR):
 
  extract_cpan_info_from_url("https://metacpan.org/author/FOO"); # -> { author => "FOO", site => "mcpan" }
 
-=item * Example #10:
+=item * Example #10 (mcpan/changes/distribution/DIST):
 
  extract_cpan_info_from_url("https://metacpan.org/changes/distribution/Module-XSOrPP");
 
@@ -406,7 +441,7 @@ Result:
 
  { dist => "Module-XSOrPP", site => "mcpan" }
 
-=item * Example #11:
+=item * Example #11 (mcpan/requires/distribution/DIST):
 
  extract_cpan_info_from_url("https://metacpan.org/requires/distribution/Module-XSOrPP?sort=[[2,1]]");
 
@@ -414,11 +449,11 @@ Result:
 
  { dist => "Module-XSOrPP", site => "mcpan" }
 
-=item * Example #12:
+=item * Example #12 (sco/dist/DIST):
 
  extract_cpan_info_from_url("http://search.cpan.org/dist/Foo-Bar/"); # -> { dist => "Foo-Bar", site => "sco" }
 
-=item * Example #13:
+=item * Example #13 (sco/perldoc?MOD):
 
  extract_cpan_info_from_url("http://search.cpan.org/perldoc?Foo::Bar");
 
@@ -426,7 +461,7 @@ Result:
 
  { module => "Foo::Bar", site => "sco" }
 
-=item * Example #14:
+=item * Example #14 (sco/search?mode=module&query=MOD):
 
  extract_cpan_info_from_url("http://search.cpan.org/search?mode=module&query=DBIx%3A%3AClass");
 
@@ -434,11 +469,27 @@ Result:
 
  { module => "DBIx::Class", site => "sco" }
 
-=item * Example #15:
+=item * Example #15 (sco/search?module=MOD):
+
+ extract_cpan_info_from_url("http://search.cpan.org/search?module=ToolSet");
+
+Result:
+
+ { module => "ToolSet", site => "sco" }
+
+=item * Example #16 (sco/search?module=MOD (#2)):
+
+ extract_cpan_info_from_url("http://search.cpan.org/search?module=Acme::Don't");
+
+Result:
+
+ { module => "Acme::Don::t", site => "sco" }
+
+=item * Example #17 (sco/~AUTHOR):
 
  extract_cpan_info_from_url("http://search.cpan.org/~unera?"); # -> { author => "unera", site => "sco" }
 
-=item * Example #16:
+=item * Example #18 (sco/~AUTHOR/DIST-REL/lib/MOD.pm):
 
  extract_cpan_info_from_url("http://search.cpan.org/~unera/DR-SunDown-0.02/lib/DR/SunDown.pm");
 
@@ -452,7 +503,7 @@ Result:
    version => 0.02,
  }
 
-=item * Example #17:
+=item * Example #19 (sco/~AUTHOR/DIST-REL/bin/SCRIPT.pm):
 
  extract_cpan_info_from_url("http://search.cpan.org/~perlancar/App-PMUtils-1.23/bin/pmpath");
 
@@ -466,11 +517,11 @@ Result:
    version => 1.23,
  }
 
-=item * Example #18:
+=item * Example #20 (cpan/authors/id/A/AU/AUTHOR):
 
  extract_cpan_info_from_url("file:/cpan/authors/id/A/AU/AUTHOR?"); # -> { author => "AUTHOR", site => "cpan" }
 
-=item * Example #19:
+=item * Example #21 (cpan/authors/id/A/AU/AUTHOR/DIST-VERSION.tar.gz):
 
  extract_cpan_info_from_url("file:/cpan/authors/id/A/AU/AUTHOR/Foo-Bar-1.0.tar.gz");
 
@@ -484,7 +535,7 @@ Result:
    version => "1.0",
  }
 
-=item * Example #20:
+=item * Example #22 (cpanratings/dist/DIST):
 
  extract_cpan_info_from_url("http://cpanratings.perl.org/dist/Submodules");
 
@@ -492,7 +543,15 @@ Result:
 
  { dist => "Submodules", site => "cpanratings" }
 
-=item * Example #21:
+=item * Example #23 (perldoc.perl.org/MOD/SUBMOD.html):
+
+ extract_cpan_info_from_url("http://perldoc.perl.org/Module/CoreList.html");
+
+Result:
+
+ { module => "Module::CoreList", site => "perldoc.perl.org" }
+
+=item * Example #24 (rt/(Public/)Dist/Display.html?Queue=DIST):
 
  extract_cpan_info_from_url("https://rt.cpan.org/Dist/Display.html?Queue=Perinci-Sub-Gen-AccessTable-DBI");
 
@@ -500,7 +559,7 @@ Result:
 
  { dist => "Perinci-Sub-Gen-AccessTable-DBI", site => "rt" }
 
-=item * Example #22:
+=item * Example #25 (unknown):
 
  extract_cpan_info_from_url("https://www.google.com/"); # -> undef
 
