@@ -1,7 +1,7 @@
 package CPAN::Module::FromURL;
 
-our $DATE = '2016-03-07'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-11-07'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -41,6 +41,11 @@ $SPEC{extract_cpan_module_from_url} = {
             args => {url=>'https://metacpan.org/release/Foo-Bar'},
             result => 'Foo::Bar',
         },
+        {
+            name => "sco/search?module",
+            args => {url=>'http://search.cpan.org/search?module=ToolSet'},
+            result => 'ToolSet',
+        },
         {
             name => 'unknown',
             args => {url=>'https://www.google.com/'},
@@ -77,7 +82,7 @@ CPAN::Module::FromURL - Extract/guess CPAN module from a URL
 
 =head1 VERSION
 
-This document describes version 0.06 of CPAN::Module::FromURL (from Perl distribution CPAN-Info-FromURL), released on 2016-03-07.
+This document describes version 0.07 of CPAN::Module::FromURL (from Perl distribution CPAN-Info-FromURL), released on 2016-11-07.
 
 =head1 FUNCTIONS
 
@@ -90,15 +95,19 @@ Examples:
 
 =over
 
-=item * Example #1:
+=item * Example #1 (mcpan/pod/MOD):
 
  extract_cpan_module_from_url("https://metacpan.org/pod/Foo::Bar"); # -> "Foo::Bar"
 
-=item * Example #2:
+=item * Example #2 (mcpan/release/DIST):
 
  extract_cpan_module_from_url("https://metacpan.org/release/Foo-Bar"); # -> "Foo::Bar"
 
-=item * Example #3:
+=item * Example #3 (sco/search?module):
+
+ extract_cpan_module_from_url("http://search.cpan.org/search?module=ToolSet"); # -> "ToolSet"
+
+=item * Example #4 (unknown):
 
  extract_cpan_module_from_url("https://www.google.com/"); # -> undef
 
